var conf = require('../config/init'),
	logger = require('../app/logging/logger'),
	appPackage = require('../package.json'),
	appName = appPackage.name,
	appVersion = appPackage.version,
	classify = require('../main'),
	errno = require('errno'),
	path = require('path');

if (conf.get('help')) {
	conf.stores.argv.showHelp();
	return 0;
}

var log = logger.create('classifier'),
	cldrFilePath = conf.get('in'),
	jsFilePath = conf.get('out');

log.info('%s v%s', appName, appVersion);

if (isRelativePath(cldrFilePath))
	cldrFilePath = path.join(__dirname, cldrFilePath);
if (isRelativePath(jsFilePath))
	jsFilePath = path.join(__dirname, jsFilePath);

classify(cldrFilePath, jsFilePath, conf.get('class'), log).catch(errorHandler);

function errorHandler(err) {
	"use strict";
	var message = '';
	if (err.errno && errno.errno[err.errno])
		message += (errno.errno[err.errno].description + ', ');
	message += err.message;
	log.critical(message + '\n' + err.stack);
}

function isRelativePath(p) {
	"use strict";
	var normal = path.normalize(p);
	var absolute = path.resolve(p);
	return normal !== absolute;
}