var P = require('bluebird'),
	fs = require('fs-extra'),
	util = require('util'),
	beautify = require('js-beautify').js_beautify;

P.promisifyAll(fs);

function createExtJsClassFromCldrData(cldrData, className) {
	var extJsClassContent = [
		util.format('Ext.define(\'%s\', {', className),
		'singleton: true,',
		'data: ' + cldrData,
		'});'
	];
	extJsClassContent = beautify(extJsClassContent.join('\n'), {indent_with_tabs: true});
	return extJsClassContent;
}

function createExtJsClassFileFromCldrDataFile(cldrFilePath, jsFilePath, extJsClassName, log) {
	return fs.readFileAsync(cldrFilePath, 'utf8').tap(function () {
		log.info('CLDR file has been read from disk.');
	}).then(function (cldrData) {
		return createExtJsClassFromCldrData(cldrData, extJsClassName);
	}).tap(function () {
		log.info('JS file generated.')
	}).then(function (extJsClassContent) {
		return fs.ensureFileAsync(jsFilePath).then(function () {
			return fs.writeFileAsync(jsFilePath, extJsClassContent, {encoding: 'utf-8'}).tap(function () {
				log.info('JS file has been written to disk.');
			});
		});
	});
}

module.exports = createExtJsClassFileFromCldrDataFile;